@@ -1,5 +1,5 @@
 magmap<-
-function(data, lo=0, hi=1, flip=FALSE, range=c(0,2/3), type='quan', log=FALSE, bad=NA){
+function(data, lo=0, hi=1, flip=FALSE, range=c(0,2/3), type='quan', log=FALSE, bad=NA, clip=''){
 if(log){
 	good=is.na(data)==FALSE & is.nan(data)==FALSE & is.infinite(data)==FALSE & is.null(data)==FALSE & data>0
 	}else{
@@ -28,11 +28,12 @@ if(lo>hi){stop('lo>hi is not allowed')}
 if(lo==hi){data=rep((range[2]+range[1])/2,length(data))}
 if(lo<hi){
 	if(log){data=suppressWarnings(log10(data));lo=log10(lo);hi=log10(hi)}
-	data[data<lo]=lo
-	data[data>hi]=hi
+  losel=data<lo; hisel=data>hi
+	data[losel]=lo; data[hisel]=hi
 	data=data-lo
 	data=range[1]+(data*(range[2]-range[1])/(hi-lo))
 	if(flip){data=range[2]-data+range[1]}
+  if(clip=='NA'){data[losel]=NA;data[hisel]=NA}
 	if(log){lo=10^lo;hi=10^hi}
 }
 data[! good]=bad
